@@ -1,5 +1,5 @@
 package Yancy::Plugin::Editor;
-our $VERSION = '1.030';
+our $VERSION = '1.031';
 # ABSTRACT: Yancy content editor, admin, and management application
 
 #pod =head1 SYNOPSIS
@@ -89,9 +89,9 @@ our $VERSION = '1.030';
 #pod     % end
 #pod
 #pod =for html
-#pod
 #pod <img alt="screenshot of yancy editor showing custom element"
-#pod     src="https://raw.github.com/preaction/Yancy/master/eg/doc-site/public/screenshot-custom-element.png?raw=true" />
+#pod     src="https://raw.github.com/preaction/Yancy/master/eg/doc-site/public/screenshot-custom-element.png?raw=true"
+#pod     style="width: 600px; max-width: 100%;" />
 #pod
 #pod =head2 yancy.editor.route
 #pod
@@ -566,7 +566,7 @@ Yancy::Plugin::Editor - Yancy content editor, admin, and management application
 
 =head1 VERSION
 
-version 1.030
+version 1.031
 
 =head1 SYNOPSIS
 
@@ -654,15 +654,9 @@ available for custom applications.
         } );
     % end
 
-=begin html
-
-
-
-
-=end html
-
-<img alt="screenshot of yancy editor showing custom element"
-    src="https://raw.github.com/preaction/Yancy/master/eg/doc-site/public/screenshot-custom-element.png?raw=true" />
+=for html <img alt="screenshot of yancy editor showing custom element"
+    src="https://raw.github.com/preaction/Yancy/master/eg/doc-site/public/screenshot-custom-element.png?raw=true"
+    style="width: 600px; max-width: 100%;" />
 
 =head2 yancy.editor.route
 
